import React, { useEffect, useState } from 'react';
import axios from 'axios';

function ProductsPage() {
    const [products, setProducts] = useState([]);
    const [loading, setLoading] = useState(true);
    const [error, setError] = useState(null);

    useEffect(() => {
        axios.get('http://127.0.0.1:8000/themeApp/products/')  // Replace with your Django API endpoint
            .then(response => {
                setProducts(response.data);
                setLoading(false);
            })
            .catch(error => {
                setError(error);
                setLoading(false);
            });
    }, []);

    if (loading) return <p>Loading...</p>;
    if (error) return <p>Error loading products: {error.message}</p>;

    return (
        <div style={{ padding: '20px' }}>
            <h1 style={{ fontSize: '24px', marginBottom: '20px' }}>Products</h1>
            <ul style={{ listStyleType: 'none', padding: 0 }}>
                {products.map(product => (
                    <li key={product.id} style={{ 
                        fontSize: '18px', 
                        padding: '10px', 
                        marginBottom: '10px', 
                        border: '1px solid #ccc', 
                        borderRadius: '4px', 
                        cursor: 'pointer',
                        transition: 'box-shadow 0.3s ease-in-out',
                        display: 'flex',
                        alignItems: 'center'
                    }}
                    onMouseEnter={(e) => {
                        e.currentTarget.style.boxShadow = '0 0 20px rgba(0, 0, 0, 0.35)';
                    }}
                    onMouseLeave={(e) => {
                        e.currentTarget.style.boxShadow = 'none';
                    }}
                    >
                        <img src={product.image} alt={product.name} style={{ width: '50px', height: '50px', marginRight: '10px', borderRadius: '4px' }} />
                        {product.name}
                    </li>
                ))}
            </ul>
        </div>
    );
}

export default ProductsPage;
