import React, { useState, useEffect } from 'react';

const NavigationComponent = ({ goToNextPage, goToPreviousPage, currentPage, totalPages }) => {
  const renderDots = () => {
    const dots = [];
    for (let i = 1; i <= totalPages; i++) {
      dots.push(
        <span
          key={i}
          style={{
            fontSize: 20,
            margin: '0 2px',
            color: i === currentPage ? 'black' : 'gray',
          }}
        >
          ●
        </span>
      );
    }
    return dots;
  };

  return (
    <div style={styles.navigation}>
      <button onClick={goToPreviousPage} style={styles.navButton}>&lt;</button>
      <div style={styles.dotsContainer}>{renderDots()}</div>
      <button onClick={goToNextPage} style={styles.navButton}>&gt;</button>
    </div>
  );
};

const MoviesDisplay = ({ setOfMovies, goToNextPage, goToPreviousPage, currentPage, totalPages }) => {
  return (
    <div style={styles.moviesContainer}>
      <div style={styles.movies}>
        {setOfMovies.map((movie, index) => (
          <div key={index} style={styles.movie}>
            <img src={movie.source} alt={movie.name} style={styles.image} />
          </div>
        ))}
      </div>
      <div style={styles.dotsContainer}>
        {[...Array(totalPages)].map((_, index) => (
          <span
            key={index}
            style={{
              ...styles.dot,
              backgroundColor: index + 1 === currentPage ? 'black' : 'gray',
            }}
          />
        ))}
      </div>
      <div style={styles.navLeft}>
        <button onClick={goToPreviousPage} style={styles.navButton}>&lt;</button>
      </div>
      <div style={styles.navRight}>
        <button onClick={goToNextPage} style={styles.navButton}>&gt;</button>
      </div>
    </div>
  );
};
const Carousel = ({ showingItems, items, autoScrollInterval = 3000 }) => {
  const [currentPage, setCurrentPage] = useState(1);
  const TOTAL_PAGES = Math.ceil(items.length / showingItems);

  useEffect(() => {
    const intervalId = setInterval(nextPage, autoScrollInterval);
    return () => clearInterval(intervalId);
  }, [currentPage]);

  const previousPage = () => {
    setCurrentPage((prevPage) => (prevPage === 1 ? TOTAL_PAGES : prevPage - 1));
  };

  const nextPage = () => {
    setCurrentPage((prevPage) => (prevPage === TOTAL_PAGES ? 1 : prevPage + 1));
  };

  const groupingMovies = [];
  for (let i = 0; i < items.length; i += showingItems) {
    groupingMovies.push(items.slice(i, i + showingItems));
  }

  return (
    <div style={styles.container}>
      <div style={styles.topRow}>
        <h3 style={styles.title}>Teman</h3>
      </div>
      <div style={styles.sliderContainer}>
        <div
          style={{
            ...styles.slider,
            transform: `translateX(-${(currentPage - 1) * 100}%)`,
          }}
        >
          {groupingMovies.map((group, index) => (
            <div key={index} style={styles.page}>
              <MoviesDisplay
                setOfMovies={group}
                goToNextPage={nextPage}
                goToPreviousPage={previousPage}
                currentPage={currentPage}
                totalPages={TOTAL_PAGES}
              />
            </div>
          ))}
        </div>
        <div style={styles.dotsContainer}>
          {[...Array(TOTAL_PAGES)].map((_, index) => (
            <span
              key={index}
              style={{
                ...styles.dot,
                backgroundColor: index + 1 === currentPage ? 'black' : 'gray',
              }}
            />
          ))}
        </div>
      </div>
    </div>
  );
};


const styles = {
  container: {
    backgroundColor: '#fff',
    width: '100%',
    position: 'relative',
  },
  topRow: {
    display: 'flex',
    boxSizing: 'border-box',
    justifyContent: 'space-between',
    padding: 10,
    width: '100%',
    backgroundColor: 'white',
    alignItems: 'center',
    position: 'relative',
  },
  sliderContainer: {
    overflow: 'hidden',
    width: '100%',
    position: 'relative',
  },
  slider: {
    display: 'flex',
    transition: 'transform 0.5s ease-in-out',
    width: '100%',
  },
  page: {
    //display: 'flex',
    width: '100%',
    minWidth: '100%',
    boxSizing: 'border-box',
    position: 'relative',
 
  },
  moviesContainer: {
    position: 'relative',
  },
  movies: {
    display: 'flex',
    justifyContent: 'center',
    width: '100%',
  },
  movie: {
    flex: 1,
    margin: '0 5px',
  },
  image: {
    width: '100%',
    height: '350px', // This ensures the aspect ratio is maintained
    borderRadius: 10,
  },
  navigation: {
    position: 'absolute',
    top: '50%',
    width: '100%',
    display: 'flex',
    justifyContent: 'space-between',
    transform: 'translateY(-50%)',
    zIndex: 1, // Ensure navigation buttons are above images
  },
  navButton: {
    background: 'rgba(0, 0, 0, 0.5)',
    color: 'white',
    border: 'none',
    padding: '10px',
    cursor: 'pointer',
  },
  dotsContainer: {
    height: '10px',
  },
  navLeft: {
    position: 'absolute',
    left: 0,
    top: '50%',
    transform: 'translateY(-50%)',
  },
  navRight: {
    position: 'absolute',
    right: 0,
    top: '50%',
    transform: 'translateY(-50%)',
  },
};

export default Carousel;
